@@ -3,18 +3,23 @@
 """
 
 import operator as op
-
 from collections import OrderedDict
-from collections.abc import MutableMapping, Sequence
-from collections.abc import KeysView, ValuesView, ItemsView
+from collections.abc import (
+    ItemsView,
+    KeysView,
+    MutableMapping,
+    Sequence,
+    ValuesView,
+)
 from contextlib import contextmanager
 from shutil import rmtree
 
-from .core import Cache, ENOVAL
+from .core import ENOVAL, Cache
 
 
 def _make_compare(seq_op, doc):
     "Make compare method with Sequence semantics."
+
     def compare(self, that):
         "Compare method for deque and sequence."
         if not isinstance(that, Sequence):
@@ -70,6 +75,7 @@ class Deque(Sequence):
     [3, 2, 1, 0, 0, -1, -2, -3]
 
     """
+
     def __init__(self, iterable=(), directory=None):
         """Initialize deque instance.
 
@@ -81,9 +87,7 @@ class Deque(Sequence):
 
         """
         self._cache = Cache(directory, eviction_policy='none')
-        with self.transact():
-            self.extend(iterable)
-
+        self.extend(iterable)
 
     @classmethod
     def fromcache(cls, cache, iterable=()):
@@ -111,19 +115,16 @@ class Deque(Sequence):
         self.extend(iterable)
         return self
 
-
     @property
     def cache(self):
         "Cache used by deque."
         return self._cache
 
-
     @property
     def directory(self):
         "Directory path where deque is stored."
         return self._cache.directory
 
-
     def _index(self, index, func):
         len_self = len(self)
 
@@ -154,7 +155,6 @@ class Deque(Sequence):
 
         raise IndexError('deque index out of range')
 
-
     def __getitem__(self, index):
         """deque.__getitem__(index) <==> deque[index]
 
@@ -177,7 +177,6 @@ class Deque(Sequence):
         """
         return self._index(index, self._cache.__getitem__)
 
-
     def __setitem__(self, index, value):
         """deque.__setitem__(index, value) <==> deque[index] = value
 
@@ -196,10 +195,11 @@ class Deque(Sequence):
         :raises IndexError: if index out of range
 
         """
+
         def _set_value(key):
             return self._cache.__setitem__(key, value)
-        self._index(index, _set_value)
 
+        self._index(index, _set_value)
 
     def __delitem__(self, index):
         """deque.__delitem__(index) <==> del deque[index]
@@ -220,7 +220,6 @@ class Deque(Sequence):
         """
         self._index(index, self._cache.__delitem__)
 
-
     def __repr__(self):
         """deque.__repr__() <==> repr(deque)
 
@@ -230,7 +229,6 @@ class Deque(Sequence):
         name = type(self).__name__
         return '{0}(directory={1!r})'.format(name, self.directory)
 
-
     __eq__ = _make_compare(op.eq, 'equal to')
     __ne__ = _make_compare(op.ne, 'not equal to')
     __lt__ = _make_compare(op.lt, 'less than')
@@ -238,7 +236,6 @@ class Deque(Sequence):
     __le__ = _make_compare(op.le, 'less than or equal to')
     __ge__ = _make_compare(op.ge, 'greater than or equal to')
 
-
     def __iadd__(self, iterable):
         """deque.__iadd__(iterable) <==> deque += iterable
 
@@ -251,7 +248,6 @@ class Deque(Sequence):
         self.extend(iterable)
         return self
 
-
     def __iter__(self):
         """deque.__iter__() <==> iter(deque)
 
@@ -266,7 +262,6 @@ class Deque(Sequence):
             except KeyError:
                 pass
 
-
     def __len__(self):
         """deque.__len__() <==> len(deque)
 
@@ -275,7 +270,6 @@ class Deque(Sequence):
         """
         return len(self._cache)
 
-
     def __reversed__(self):
         """deque.__reversed__() <==> reversed(deque)
 
@@ -298,15 +292,12 @@ class Deque(Sequence):
             except KeyError:
                 pass
 
-
     def __getstate__(self):
         return self.directory
 
-
     def __setstate__(self, state):
         self.__init__(directory=state)
 
-
     def append(self, value):
         """Add `value` to back of deque.
 
@@ -322,7 +313,6 @@ class Deque(Sequence):
         """
         self._cache.push(value, retry=True)
 
-
     def appendleft(self, value):
         """Add `value` to front of deque.
 
@@ -338,7 +328,6 @@ class Deque(Sequence):
         """
         self._cache.push(value, side='front', retry=True)
 
-
     def clear(self):
         """Remove all elements from deque.
 
@@ -352,7 +341,6 @@ class Deque(Sequence):
         """
         self._cache.clear(retry=True)
 
-
     def count(self, value):
         """Return number of occurrences of `value` in deque.
 
@@ -371,7 +359,6 @@ class Deque(Sequence):
         """
         return sum(1 for item in self if value == item)
 
-
     def extend(self, iterable):
         """Extend back side of deque with values from `iterable`.
 
@@ -381,7 +368,6 @@ class Deque(Sequence):
         for value in iterable:
             self.append(value)
 
-
     def extendleft(self, iterable):
         """Extend front side of deque with value from `iterable`.
 
@@ -396,7 +382,6 @@ class Deque(Sequence):
         for value in iterable:
             self.appendleft(value)
 
-
     def peek(self):
         """Peek at value at back of deque.
 
@@ -423,7 +408,6 @@ class Deque(Sequence):
             raise IndexError('peek from an empty deque')
         return value
 
-
     def peekleft(self):
         """Peek at value at front of deque.
 
@@ -450,7 +434,6 @@ class Deque(Sequence):
             raise IndexError('peek from an empty deque')
         return value
 
-
     def pop(self):
         """Remove and return value at back of deque.
 
@@ -477,7 +460,6 @@ class Deque(Sequence):
             raise IndexError('pop from an empty deque')
         return value
 
-
     def popleft(self):
         """Remove and return value at front of deque.
 
@@ -502,7 +484,6 @@ class Deque(Sequence):
             raise IndexError('pop from an empty deque')
         return value
 
-
     def remove(self, value):
         """Remove first occurrence of `value` in deque.
 
@@ -540,7 +521,6 @@ class Deque(Sequence):
 
         raise ValueError('deque.remove(value): value not in deque')
 
-
     def reverse(self):
         """Reverse deque in place.
 
@@ -563,7 +543,6 @@ class Deque(Sequence):
         del temp
         rmtree(directory)
 
-
     def rotate(self, steps=1):
         """Rotate deque right by `steps`.
 
@@ -612,9 +591,7 @@ class Deque(Sequence):
                 else:
                     self.append(value)
 
-
-    __hash__ = None
-
+    __hash__ = None  # type: ignore
 
     @contextmanager
     def transact(self):
@@ -665,6 +642,7 @@ class Index(MutableMapping):
     ('c', 3)
 
     """
+
     def __init__(self, *args, **kwargs):
         """Initialize index in directory and update items.
 
@@ -692,7 +670,6 @@ class Index(MutableMapping):
         self._cache = Cache(directory, eviction_policy='none')
         self.update(*args, **kwargs)
 
-
     @classmethod
     def fromcache(cls, cache, *args, **kwargs):
         """Initialize index using `cache` and update items.
@@ -720,19 +697,16 @@ class Index(MutableMapping):
         self.update(*args, **kwargs)
         return self
 
-
     @property
     def cache(self):
         "Cache used by index."
         return self._cache
 
-
     @property
     def directory(self):
         "Directory path where items are stored."
         return self._cache.directory
 
-
     def __getitem__(self, key):
         """index.__getitem__(key) <==> index[key]
 
@@ -756,7 +730,6 @@ class Index(MutableMapping):
         """
         return self._cache[key]
 
-
     def __setitem__(self, key, value):
         """index.__setitem__(key, value) <==> index[key] = value
 
@@ -774,7 +747,6 @@ class Index(MutableMapping):
         """
         self._cache[key] = value
 
-
     def __delitem__(self, key):
         """index.__delitem__(key) <==> del index[key]
 
@@ -797,7 +769,6 @@ class Index(MutableMapping):
         """
         del self._cache[key]
 
-
     def setdefault(self, key, default=None):
         """Set and get value for `key` in index using `default`.
 
@@ -822,7 +793,6 @@ class Index(MutableMapping):
             except KeyError:
                 _cache.add(key, default, retry=True)
 
-
     def peekitem(self, last=True):
         """Peek at key and value item pair in index based on iteration order.
 
@@ -841,7 +811,6 @@ class Index(MutableMapping):
         """
         return self._cache.peekitem(last, retry=True)
 
-
     def pop(self, key, default=ENOVAL):
         """Remove corresponding item for `key` from index and return value.
 
@@ -872,7 +841,6 @@ class Index(MutableMapping):
             raise KeyError(key)
         return value
 
-
     def popitem(self, last=True):
         """Remove and return item pair.
 
@@ -907,7 +875,6 @@ class Index(MutableMapping):
 
         return key, value
 
-
     def push(self, value, prefix=None, side='back'):
         """Push `value` onto `side` of queue in index identified by `prefix`.
 
@@ -939,7 +906,6 @@ class Index(MutableMapping):
         """
         return self._cache.push(value, prefix, side, retry=True)
 
-
     def pull(self, prefix=None, default=(None, None), side='front'):
         """Pull key and value item pair from `side` of queue in index.
 
@@ -980,7 +946,6 @@ class Index(MutableMapping):
         """
         return self._cache.pull(prefix, default, side, retry=True)
 
-
     def clear(self):
         """Remove all items from index.
 
@@ -994,7 +959,6 @@ class Index(MutableMapping):
         """
         self._cache.clear(retry=True)
 
-
     def __iter__(self):
         """index.__iter__() <==> iter(index)
 
@@ -1003,7 +967,6 @@ class Index(MutableMapping):
         """
         return iter(self._cache)
 
-
     def __reversed__(self):
         """index.__reversed__() <==> reversed(index)
 
@@ -1020,7 +983,6 @@ class Index(MutableMapping):
         """
         return reversed(self._cache)
 
-
     def __len__(self):
         """index.__len__() <==> len(index)
 
@@ -1029,7 +991,6 @@ class Index(MutableMapping):
         """
         return len(self._cache)
 
-
     def keys(self):
         """Set-like object providing a view of index keys.
 
@@ -1044,7 +1005,6 @@ class Index(MutableMapping):
         """
         return KeysView(self)
 
-
     def values(self):
         """Set-like object providing a view of index values.
 
@@ -1059,7 +1019,6 @@ class Index(MutableMapping):
         """
         return ValuesView(self)
 
-
     def items(self):
         """Set-like object providing a view of index items.
 
@@ -1074,18 +1033,14 @@ class Index(MutableMapping):
         """
         return ItemsView(self)
 
-
-    __hash__ = None
-
+    __hash__ = None  # type: ignore
 
     def __getstate__(self):
         return self.directory
 
-
     def __setstate__(self, state):
         self.__init__(state)
 
-
     def __eq__(self, other):
         """index.__eq__(other) <==> index == other
 
@@ -1119,7 +1074,6 @@ class Index(MutableMapping):
         else:
             return all(self[key] == other.get(key, ENOVAL) for key in self)
 
-
     def __ne__(self, other):
         """index.__ne__(other) <==> index != other
 
@@ -1143,7 +1097,6 @@ class Index(MutableMapping):
         """
         return not self == other
 
-
     def memoize(self, name=None, typed=False):
         """Memoizing cache decorator.
 
@@ -1200,7 +1153,6 @@ class Index(MutableMapping):
         """
         return self._cache.memoize(name, typed)
 
-
     @contextmanager
     def transact(self):
         """Context manager to perform a transaction by locking the index.
@@ -1228,7 +1180,6 @@ class Index(MutableMapping):
         with self._cache.transact(retry=True):
             yield
 
-
     def __repr__(self):
         """index.__repr__() <==> repr(index)
 
